package com.example.tcc.api;

import com.example.tcc.document.models.Person;
import com.example.tcc.service.PersonService;
import com.example.tcc.service.exception.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

import static com.example.tcc.service.utils.Constants.ERROR_MESSAGE;
import static com.example.tcc.service.utils.Constants.MISSING_ARGUMENTS;

@RestController
@RequestMapping(produces = MediaType.APPLICATION_JSON_VALUE)
public class PersonController {

	@Autowired
	PersonService personService;

	@GetMapping("public/person/{name}")
	public ResponseEntity<Object> findPersonByName(@PathVariable String name) {
		try {
			return ResponseEntity.ok(personService.findPerson(name));
		} catch (PersonNotFoundException e) {
			Map<String, String> error = new HashMap<>();
			error.put(ERROR_MESSAGE, e.getMessage());
			return ResponseEntity.badRequest().body(error);
		}
	}

	@GetMapping("public/person/search")
	public ResponseEntity<Object> searchPeople(@RequestParam String input, @RequestParam Integer page) {
		return ResponseEntity.ok(personService.searchPeople(input, page));
	}

	@GetMapping("admin/person/list")
	public ResponseEntity<Object> findAll(@RequestParam Integer page) {
		return ResponseEntity.ok(personService.findAll(page));
	}

	@PostMapping("admin/person/save")
	public ResponseEntity<Object> savePerson(@RequestBody Person person) {
		try {
			personService.savePerson(person);
			return ResponseEntity.ok().build();
		} catch (RepeatedPersonException | WorkNotFoundException | MissingRoleException e) {
			Map<String, String> error = new HashMap<>();
			error.put(ERROR_MESSAGE, e.getMessage());
			return ResponseEntity.badRequest().body(error);
		} catch (MissingArgumentsException e) {
			Map<String, Object> error = new HashMap<>();
			error.put(ERROR_MESSAGE, e.getMessage());
			error.put(MISSING_ARGUMENTS, e.getArguments());
			return ResponseEntity.badRequest().body(error);
		}
	}

	@DeleteMapping("admin/person/delete")
	public ResponseEntity<Object> deletePerson(@RequestParam String id) {
		try {
			personService.deletePerson(id);
			return ResponseEntity.noContent().build();
		} catch (PersonNotFoundException e) {
			Map<String, String> error = new HashMap<>();
			error.put(ERROR_MESSAGE, e.getMessage());
			return ResponseEntity.badRequest().body(error);
		}
	}
}
