import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/data/dtos/login_to_session_dto.dart';
import 'package:tcc_app/exceptions/app_exception.dart';
import 'package:tcc_app/services/user_service.dart';

part 'user_event.dart';
part 'user_state.dart';

class UserBloc extends Bloc<UserEvent, UserState> {
  final UserService userService;

  UserBloc({required this.userService}) : super(UserState()) {
    on<ResetStateUserEvent>((_, emit) => emit(UserState()));
    on<RegisterUserEvent>((event, emit) => _registerAndLoginUser(emit, event));
  }

  void _registerAndLoginUser(Emitter emit, RegisterUserEvent event) async {
    try {
      emit(LoadingUserState());

      final List<String> dateToList = event.birthDate.split('/');
      final String formatedBirthDate =
          '${dateToList[2]}-${dateToList[1]}-${dateToList[0]}';

      final LoginToSessionDto response = await userService.registerUser(
        name: event.name,
        username: event.username,
        password: event.password,
        birthDate: formatedBirthDate,
        email: event.email,
      );

      emit(RegisteredUserState(
        password: response.password,
        username: response.username,
      ));
    } on AppException catch (e) {
      emit(ErrorUserState(errorMessage: e.message));
      if (event.onError != null) event.onError!(e.message);
    }
  }
}
