// ignore_for_file: public_member_api_docs, sort_constructors_first
import 'dart:convert';
import 'dart:typed_data';

import 'package:flutter/foundation.dart';
import 'package:tcc_app/constants/enums.dart';
import 'package:tcc_app/constants/maps.dart';
import 'package:tcc_app/data/dtos/statistics_model_dto.dart';

class ProfileDto {
  final String profileCover;
  final CoverOption coverOption;
  final String name;
  final String username;
  final Uint8List? photo;
  final List<StatisticsDto> statistics;

  ProfileDto({
    required this.name,
    required this.username,
    required this.profileCover,
    required this.coverOption,
    required this.photo,
    required this.statistics,
  });

  ProfileDto.fromResponseContent(Map content)
      : name = content['name'],
        username = content['username'],
        profileCover = content['profileCover'] ?? '',
        coverOption = enumConverter[content['coverOption']],
        photo = _tryGetPhoto(content['photo']),
        statistics = content['statisticsList'] != null
            ? content['statisticsList']
            .map<StatisticsDto>(
                (statistics) => StatisticsDto.fromResponseContent(statistics))
            .toList()
            : [];

  static Uint8List? _tryGetPhoto(String? photo) {
    try {
      if (photo != null) return base64Decode(photo);
      return null;
    } catch (_) {
      return null;
    }
  }

  Future<Map> toMap() async => {
        'name': name,
        'username': username,
        'profileCover': profileCover,
        'coverOption': enumConverter[coverOption],
        'photo': photo != null ? base64Encode(photo!) : null,
      };

  ProfileDto copyWith({
    String? profileCover,
    CoverOption? coverOption,
    String? name,
    String? username,
    Uint8List? photo,
    List<StatisticsDto>? statistics,
  }) {
    return ProfileDto(
      profileCover: profileCover ?? this.profileCover,
      coverOption: coverOption ?? this.coverOption,
      name: name ?? this.name,
      username: username ?? this.username,
      photo: photo ?? this.photo,
      statistics: statistics ?? this.statistics,
    );
  }

  @override
  bool operator ==(covariant ProfileDto other) {
    if (identical(this, other)) return true;

    return
      other.profileCover == profileCover &&
      other.coverOption == coverOption &&
      other.name == name &&
      other.username == username &&
      other.photo == photo &&
      listEquals(other.statistics, statistics);
  }

  @override
  int get hashCode {
    return profileCover.hashCode ^
      coverOption.hashCode ^
      name.hashCode ^
      username.hashCode ^
      photo.hashCode ^
      statistics.hashCode;
  }
}
