class ReadWorkDetailsDto {
  final String id;
  final String name;
  final String cover;
  final String type;
  final double averageScore;
  final List<String> tags;
  final int? releaseYear;
  final String? synopsis;
  final int? minuteDuration;
  final int? episodeNumber;
  final int? pageNumber;
  final String? productionCompany;
  final List<ReadWorkDetailsPersonWork>? person;

  ReadWorkDetailsDto(
      {required this.id,
      required this.name,
      required this.cover,
      required this.type,
      required this.averageScore,
      required this.tags,
      this.releaseYear,
      this.productionCompany,
      this.synopsis,
      this.minuteDuration,
      this.episodeNumber,
      this.pageNumber,
      this.person});

  ReadWorkDetailsDto.fromResponseContent(Map content)
      : id = content['id'],
        name = content['name'],
        synopsis = content['synopsis'],
        cover = content['cover'],
        type = content['type'],
        averageScore = content['averageScore'] ?? 0,
        releaseYear = content['releaseYear'],
        tags = content['tags'].cast<String>(),
        productionCompany = content['productionCompany'] ?? content['developer'],
        minuteDuration = content['minuteDuration'],
        episodeNumber = content['episodeNumber'],
        pageNumber = content['pageNumber'],
        person = content['people']?.map<ReadWorkDetailsPersonWork>((p) =>
            ReadWorkDetailsPersonWork(
                person: ReadWorkDetailsPerson(
                    id: p['person']['id'],
                    name: p['person']['name'],
                    photo: p['person']['photo']),
                role: p['role'],
                isMain: p['isMain'])).toList().cast<ReadWorkDetailsPersonWork>();
}

class ReadWorkDetailsPerson {
  final String id;
  final String name;
  final String photo;

  ReadWorkDetailsPerson(
      {required this.id, required this.name, required this.photo});
}

class ReadWorkDetailsPersonWork {
  final ReadWorkDetailsPerson person;
  final String role;
  final bool isMain;

  ReadWorkDetailsPersonWork(
      {required this.person, required this.role, required this.isMain});
}
