import 'package:dio/dio.dart';
import 'package:jwt_decoder/jwt_decoder.dart';
import 'package:tcc_app/data/dtos/login_request_dto.dart';
import 'package:tcc_app/data/repositories/app_repository.dart';
import 'package:tcc_app/data/repositories/local_device_repository.dart';

class AuthRepository extends AppRepository {
  Dio dio;
  final LocalDeviceRepository localRepository = LocalDeviceRepository.instance;

  AuthRepository({required this.dio});

  Future<Response?>? login({required LoginRequestDto params}) async {
    try {
      final Map data = params.toMap();

      return await dio.post(
        '/public/login',
        data: data,
        options: Options(contentType: Headers.formUrlEncodedContentType),
      );
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }

  Future<String?> verifyToken() async {
    if (await localRepository.containsKey(BEARER_TOKEN_KEY)) {
      final String? bearerToken = await localRepository.getBearerToken();

      if (!JwtDecoder.isExpired(bearerToken ?? '')) {
        return bearerToken;
      } else {
        try {
          final refreshToken = await localRepository.getRefreshToken();
          final Response renewTokenResponse = await dio.get(
              'https://tcc-b-e.herokuapp.com/public/token/refresh',
              options:
                  Options(headers: {'Authorization': 'Bearer $refreshToken'}));

          await localRepository
              .setRefreshToken(renewTokenResponse.data['access_token']);

          return (renewTokenResponse.data['access_token']);
        } catch (e) {
          return null;
        }
      }
    }
  }
}
