import 'package:dio/dio.dart';
import 'package:tcc_app/data/dtos/profile_dto.dart';
import 'package:tcc_app/data/dtos/register_request_dto.dart';
import 'package:tcc_app/data/repositories/app_repository.dart';

class UserRepository extends AppRepository {
  Dio dio;

  UserRepository({required this.dio});

  Future<Response?>? registerUser({required RegisterRequestDto params}) async {
    try {
      final Map data = params.toMap();

      return await dio.post('/public/user/save', data: data);
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }

  Future<Response?>? getUserProfile({required String username}) async {
    try {
      return await dio.get('/public/user/$username');
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }

  Future<void>? editUserProfile({required ProfileDto profile}) async {
    try {
      final data = await profile.toMap(); 

      await dio.put('/api/user/edit',data:  data);
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }
}
