import 'package:dio/dio.dart';
import 'package:flutter/widgets.dart';
import 'package:tcc_app/data/dtos/work_in_personal_list_dto.dart';
import 'package:tcc_app/data/dtos/work_user_status_dto.dart';
import 'package:tcc_app/data/repositories/app_repository.dart';

class WorkRepository extends AppRepository {
  Dio dio;

  WorkRepository({required this.dio});

  Future<Response?>? fetchRecommendationFromDataBase({String? type}) async {
    try {
      return await dio.get('/api/work/recommendations?type=${type ?? 'any'}');
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }

  Future<Response?>? fetchWorksByTagsFromDataBase({String? type}) async {
    try {
      return await dio.get('/public/work/by-tags?type=${type ?? 'any'}');
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }

  Future<Response?>? fetchFamousWorksFromDataBase({String? type}) async {
    try {
      return await dio.get('/public/work/famous?type=${type ?? 'any'}');
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }

  Future<Response?>? fetchWorkById(String workId) async {
    try {
      return await dio.get('/public/work?id=$workId');
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }

  Future<Response?>? fetchUserPersonalList(String username) async {
    try {
      return await dio.get('/public/user/$username/work-list');
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }

  Future<Response?>? fetchWorkInUserList(String username, String workId) async {
    try {
      return await dio.get('/public/user/$username/work-list/$workId');
    } on DioError catch (e, stackTrace) {
      //super.errorHandler(e, stackTrace);
      return null;
    }
  }

  Future<Response?>? upsertWorkInUserList(
      String username, String workId, WorkUserStatusDto work) async {
    try {
      debugPrint("work: {id: $workId}, status: ${work.status}, score: ${work.score}");
      return await dio.post('/api/work/add-work-to-list', data: {
        "work": {"id": workId},
        "status": work.status,
        "score": work.score,
        if (work.progress != null) "progress": work.progress
      });
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }

  Future<Response?>? fetchWorkByQuery(
      {required String query, required String type, int page = 0}) async {
    try {
      return await dio.get('/public/work/search?input=$query&type=$type&page=$page');
    } on DioError catch (e, stackTrace) {
      super.errorHandler(e, stackTrace);
    }
  }
}
