import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/blocs/session/session_bloc.dart';
import 'package:tcc_app/blocs/user/user_bloc.dart';
import 'package:tcc_app/screens/routes.dart';
import 'package:tcc_app/services/auth_service.dart';
import 'package:tcc_app/data/unit_of_work.dart';
import 'package:tcc_app/data/repositories/local_device_repository.dart';
import 'package:tcc_app/services/person_service.dart';
import 'package:tcc_app/services/user_service.dart';
import 'package:tcc_app/services/work_service.dart';

void main() {
  //init repositories
  LocalDeviceRepository localRepository = LocalDeviceRepository();
  UnitOfWork appRepositories = UnitOfWork(localRepository: localRepository);

  //init services
  AuthService(
    authRepository: appRepositories.auth,
    localRepository: localRepository,
  );

  UserService(userRepository: appRepositories.user);

  WorkService(workRepository: appRepositories.works);

  PersonService(personRepository: appRepositories.people);

  runApp(const TccApp());
}

class TccApp extends StatelessWidget {
  const TccApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    UserBloc userBloc = UserBloc(userService: UserService.instance);
    SessionBloc sessionBloc = SessionBloc(
      userService: UserService.instance,
      authService: AuthService.instance,
      userBloc: userBloc,
    );

    return MultiBlocProvider(
      providers: [
        BlocProvider(create: (context) => userBloc),
        BlocProvider(create: (context) => sessionBloc),
      ],
      child: 
           MaterialApp(
            title: 'Flutter Demo',
            theme: ThemeData(
              primarySwatch: Colors.indigo,
              colorScheme: ColorScheme(
                primary: Colors.white,
                onPrimary: Colors.grey[350]!,
                secondary: const Color(0xFF3AAA96),
                onSecondary: Colors.white,
                background: const Color(0xFF203C6D),
                onBackground: Colors.black38,
                surface: Colors.white,
                error: const Color(0xFFC02222),
                onError: const Color(0xFFE08B8B),
                onSurface: Colors.grey[350]!,
                brightness: Brightness.dark,
              ),
              fontFamily: 'Proxima Nova',
            ),
            initialRoute: loginScreenRoute,
            routes: routes,
          ),     
      
    );
  }
}
