import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:image_picker/image_picker.dart';
import 'package:tcc_app/blocs/session/session_bloc.dart';
import 'package:tcc_app/blocs/session/session_event.dart';
import 'package:tcc_app/constants/enums.dart';
import 'package:tcc_app/screens/edit_profile/bloc/edit_profile_bloc.dart';
import 'package:tcc_app/screens/edit_profile/widgets/choose_cover_dialog.dart';
import 'package:tcc_app/screens/routes.dart';

class EditProfile extends StatelessWidget {
  EditProfile({Key? key}) : super(key: key);

  final GlobalKey<FormState> _nameForm = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    return BlocConsumer<EditProfileBloc, EditProfileState>(
      listener: (ctx, state) {
        if (state is EditProfileSaved) {
          Navigator.popUntil(context, ModalRoute.withName('/home-screen'));

          Navigator.pushNamed(context, profileScreenRoute);
        }
      },
      builder: (ctx, state) {
        return Scaffold(
          appBar: AppBar(
            foregroundColor: Colors.white,
            backgroundColor: const Color(0xFF2E2E2E),
            toolbarHeight: 69.0,
            centerTitle: true,
            title: const Text(
              'Editar perfil',
              style: TextStyle(
                fontSize: 30.0,
                fontWeight: FontWeight.bold,
              ),
            ),
            leading: IconButton(
              onPressed: () => Navigator.pop(context),
              icon: const Icon(Icons.chevron_left_rounded, size: 45),
            ),
          ),
          body: SingleChildScrollView(
            physics: const BouncingScrollPhysics(),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Stack(
                  clipBehavior: Clip.none,
                  alignment: Alignment.center,
                  children: [
                    Container(
                      height: 270.0,
                      width: double.infinity,
                      padding: EdgeInsets.only(
                          right: 24.0,
                          left: 24.0,
                          top: MediaQuery.of(context).padding.top,
                          bottom: 55.0),
                      color: const Color(0xFF9B9B9B),
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          const Text('Configurações da capa',
                              style: TextStyle(fontSize: 24.0)),
                          OutlinedButton(
                            style: OutlinedButton.styleFrom(
                                backgroundColor:
                                    state.editedUserProfile?.coverOption ==
                                            CoverOption.choose
                                        ? Colors.white
                                        : const Color(0xFF9B9B9B),
                                side: const BorderSide(
                                  width: 2.0,
                                  color: Colors.white,
                                ),
                                shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(35.0),
                                )),
                            onPressed: state.isLoading ?? false
                                ? null
                                : () async {
                                    final test = await chooseCoverDialog(
                                        context: context);

                                    if (test != null) {
                                      context.read<EditProfileBloc>().add(
                                          SelectCoverImageEvent(
                                              coverUrl: test));
                                    }
                                  },
                            child: Text(
                              'Selecionar obra',
                              style: TextStyle(
                                  fontWeight: FontWeight.bold,
                                  fontSize: 18.0,
                                  color: state.editedUserProfile?.coverOption ==
                                          CoverOption.choose
                                      ? const Color(0xFF9B9B9B)
                                      : Colors.white),
                            ),
                          ),
                          Row(
                            children: [
                              CupertinoSwitch(
                                  value: state.editedUserProfile?.coverOption ==
                                      CoverOption.cycleFavorites,
                                  onChanged: state.isLoading ?? false
                                      ? null
                                      : (_) => context
                                          .read<EditProfileBloc>()
                                          .add(ToggleCycleFavoritesEvent())),
                              const SizedBox(width: 8.0),
                              const Expanded(
                                child: Text(
                                  'Circular entre obras com maior nota da sua lista',
                                  style: TextStyle(
                                    fontWeight: FontWeight.bold,
                                    fontSize: 18.0,
                                  ),
                                ),
                              ),
                            ],
                          ),
                        ],
                      ),
                    ),
                    Positioned(
                      bottom: -55,
                      child: GestureDetector(
                        onTap: state.isLoading ?? false
                            ? null
                            : () async {
                                final ImagePicker _picker = ImagePicker();

                                final XFile? image = await _picker.pickImage(
                                  source: ImageSource.gallery,
                                  imageQuality: 50,
                                );

                                if (image != null) {
                                  context.read<EditProfileBloc>().add(
                                        ChangeProfilePictureEvent(
                                          picture: File(image.path),
                                        ),
                                      );
                                }
                              },
                        child: Container(
                          height: 115,
                          width: 115,
                          decoration: BoxDecoration(
                            shape: BoxShape.circle,
                            color: Colors.black,
                            image: state.editedUserProfile?.photo != null
                                ? DecorationImage(
                                    image: MemoryImage(
                                        state.editedUserProfile!.photo!),
                                    fit: BoxFit.cover,
                                    opacity: .8,
                                  )
                                : null,
                          ),
                          child: const Center(
                            child: Text(
                              'Editar foto',
                              textAlign: TextAlign.center,
                              style: TextStyle(
                                  fontSize: 18.0,
                                  fontWeight: FontWeight.bold,
                                  decoration: TextDecoration.underline,
                                  color: Colors.white),
                            ),
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
                const SizedBox(height: 55),
                Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 36.0),
                  child: TextFormField(
                    initialValue: state.editedUserProfile?.name,
                    enabled: !(state.isLoading ?? false),
                    decoration: const InputDecoration(helperText: 'Nome'),
                    onChanged: (name) {
                      context
                          .read<EditProfileBloc>()
                          .add(ChangeNameEvent(name: name));
                    },
                  ),
                ),
                SizedBox(height: MediaQuery.of(context).size.height / 5.5),
                Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 36.0),
                  child: Align(
                    alignment: Alignment.centerRight,
                    child: TextButton(
                      style: TextButton.styleFrom(
                        backgroundColor: Colors.black54,
                        padding: const EdgeInsets.symmetric(
                            horizontal: 12, vertical: 8),
                        shape: const RoundedRectangleBorder(
                          borderRadius: BorderRadius.all(
                            Radius.circular(16.0),
                          ),
                        ),
                      ),
                      clipBehavior: Clip.antiAlias,
                      onPressed: state.isLoading ?? false
                          ? null
                          : () => context
                              .read<EditProfileBloc>()
                              .add(SaveEditProfileEvent()),
                      child: state.isLoading ?? false
                          ? ConstrainedBox(
                              constraints: const BoxConstraints.tightFor(
                                width: 20.0,
                                height: 20.0,
                              ),
                              child: const CircularProgressIndicator(),
                            )
                          : const Text(
                              'SALVAR',
                              style: TextStyle(
                                  fontSize: 14.0, fontWeight: FontWeight.bold),
                            ),
                    ),
                  ),
                ),
                SizedBox(height: MediaQuery.of(context).padding.bottom + 15)
              ],
            ),
          ),
        );
      },
    );
  }
}
