import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/screens/edit_profile/bloc/edit_profile_bloc.dart';
import 'package:tcc_app/screens/personal_list/widgets/personal_grid.dart';
import 'package:tcc_app/widgets/work_card.dart';

Future<String?> chooseCoverDialog({
  required BuildContext context,
}) async {
  if (context.read<EditProfileBloc>().state.works == null) {
    context.read<EditProfileBloc>().add(LoadPersonalListEvent());
  }

  return await showDialog(
      context: context,
      barrierColor: Colors.black38,
      builder: (ctx) {
        return Dialog(
          child: ConstrainedBox(
            constraints: BoxConstraints.tightFor(
              height: MediaQuery.of(context).size.height,
            ),
            child: BlocBuilder<EditProfileBloc, EditProfileState>(
              bloc: context.read<EditProfileBloc>(),
              builder: (context, state) {
                if (state.isLoading ?? false) {
                  return const Center(child: CircularProgressIndicator());
                }
                if (state.works == null) {
                  return const Center(
                    child: const Text(
                        'Sem obras adicionadas em sua lista pessoal para se mostrar'),
                  );
                }
                return SingleChildScrollView(
                  child: GridView.builder(
                    scrollDirection: Axis.vertical,
                    physics: const BouncingScrollPhysics(),
                    shrinkWrap: true,
                    padding: const EdgeInsets.all(12),
                    gridDelegate:
                        const SliverGridDelegateWithFixedCrossAxisCount(
                      crossAxisCount: 3,
                      mainAxisExtent: 150,
                      mainAxisSpacing: 10,
                    ),
                    itemCount: state.works!.length,
                    itemBuilder: (BuildContext ctx, int index) {
                      final work = state.works![index];
                      return GestureDetector(
                        onTap: () => Navigator.pop(context, work.work.cover),
                        child: WorkCard(coverUrl: work.work.cover, name: work.work.name),
                      );
                    },
                  ),
                );
              },
            ),
          ),
        );
      });
}
