import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/constants/enums.dart';
import 'package:tcc_app/exceptions/app_exception.dart';
import 'package:tcc_app/services/work_service.dart';
import 'package:tcc_app/view_model/work_view_model.dart';

part 'home_event.dart';
part 'home_state.dart';

class HomeBloc extends Bloc<HomeEvent, HomeState> {
  WorkService workService;

  HomeBloc({required this.workService}) : super(HomeLoadingState()) {
    on<LoadHomeEvent>((event, emit) => _loadHome(emit));
    on<SelectHomeFilterEvent>((event, emit)=> _loadHomeWithFilter(event, emit));
    add(LoadHomeEvent());
  }

  void _loadHome(Emitter emit) async {
    try {
      emit(HomeLoadingState());
      final List<WorkViewModel>? recommendationWorks = await workService.getRecommendations();
      final List<WorkViewModel>? famousWorks = await workService.getFamousWorks();
      final Map<String, List<WorkViewModel>>? worksByTags = await workService.getWorksByTags();
     
      if (recommendationWorks == null || recommendationWorks.isEmpty) {
        emit(NoRecommendationHomeState(
          worksByTags: worksByTags,
          famousWorks: famousWorks,
        ));
      } else {
        emit(HomeState(
          recommendedWorks: recommendationWorks,
          worksByTags: worksByTags,
          famousWorks: famousWorks,
        ));
      }
    } on AppException catch (e) {
      emit(HomeErrorState(e.message));
    } on Exception catch (_) {
      emit(HomeErrorState('Unknown Error'));
    }
  }

  _loadHomeWithFilter(SelectHomeFilterEvent event, Emitter emit) async {
    try {
      if (event.filter == state.filter) {
        emit(state.copyWith(filter: HomeFilters.none, isLoading: true,));
        add(LoadHomeEvent());
      } else {
        emit(state.copyWith(filter: event.filter, isLoading: true));
        final String type = event.filter.toString().split('.').last;
        final List<WorkViewModel>? recommendationWorks = await workService.getRecommendations(type: type);
        final List<WorkViewModel>? famousWorks = await workService.getFamousWorks(type: type);
        final Map<String, List<WorkViewModel>>? worksByTags = await workService.getWorksByTags(type: type);

        if (recommendationWorks == null || recommendationWorks.isEmpty) {
          emit(NoRecommendationHomeState());
        } else {
          if(state.filter == event.filter) {
            emit(state.copyWith(
              recommendedWorks: recommendationWorks,
              worksByTags: worksByTags,
              famousWorks: famousWorks,
              isLoading: false,
            ));
          }
        }
      }
    } on AppException catch (e) {
      emit(HomeErrorState(e.message));
    }
  }
}
