import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/constants/enums.dart';
import 'package:tcc_app/screens/home/widgets/home_drawer.dart';
import 'package:tcc_app/screens/home/widgets/home_filter_widget.dart';
import 'package:tcc_app/screens/home/widgets/work_preview.dart';
import 'package:tcc_app/screens/home/bloc/home_bloc.dart';
import 'package:tcc_app/screens/routes.dart';

class HomeScreen extends StatefulWidget {
  const HomeScreen({Key? key}) : super(key: key);

  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  late Image backgroundCover;
  @override
  void initState() {
    super.initState();

    backgroundCover =
        Image.asset('assets/images/background_image.png', fit: BoxFit.cover);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();

    precacheImage(backgroundCover.image, context);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      drawer: const HomeDrawer(),
      body: Stack(
        children: [
          ConstrainedBox(
            constraints: const BoxConstraints.expand(),
            child: backgroundCover,
          ),
          Container(
            height: double.infinity,
            width: double.infinity,
            color: Colors.black45,
          ),
          SafeArea(
            child: LayoutBuilder(
              builder: (context, constraints) {
                constraints = constraints.copyWith(
                  maxHeight: constraints.maxHeight - 140.0
                );

                return RefreshIndicator(
                  onRefresh: () async {
                    context.read<HomeBloc>().add(LoadHomeEvent());
                  },
                  child: CustomScrollView(
                    physics: const BouncingScrollPhysics(),
                    slivers: [
                      SliverAppBar(
                        title: const Text(
                          'Home',
                          style: TextStyle(
                            color: Colors.white,
                            fontWeight: FontWeight.bold,
                            letterSpacing: 5.0,
                            fontSize: 36.0,
                          ),
                        ),
                        actions: [
                          IconButton(
                              onPressed: () => Navigator.pushNamed(context, searchScreenRoute),
                              icon: const Icon(
                                Icons.search_outlined,
                                color: Colors.white,
                                size: 30.0,
                              )),
                          //
                        ],
                        floating: true,
                        elevation: 0.0,
                        backgroundColor: Colors.black26,
                        centerTitle: true,
                      ),
                      BlocBuilder<HomeBloc, HomeState>(
                        builder: (context, state) {
                          switch (state.runtimeType) {
                            case HomeLoadingState:
                              return SliverToBoxAdapter(
                                child: ConstrainedBox(
                                  constraints: constraints,
                                  child: const Center(
                                    child: CircularProgressIndicator(
                                      color: Colors.white,
                                    ),
                                  ),
                                ),
                              );
                            case HomeErrorState:
                              return SliverToBoxAdapter(
                                  child: Center(
                                child: Text(
                                  (state as HomeErrorState).errorMessage,
                                  style: TextStyle(
                                      color: Theme.of(context).colorScheme.error,
                                      fontSize: 24.0),
                                ),
                              ));
                            default:
                              return SliverToBoxAdapter(
                                child: Column(
                                  children: [
                                    const SizedBox(height: 20),SizedBox(
                                        height: 40,
                                        child: ListView(
                                          physics: const BouncingScrollPhysics(),
                                          padding: const EdgeInsets.symmetric(
                                          horizontal: 18.0),
                                          scrollDirection: Axis.horizontal,
                                          children: const [
                                              HomeFilterWidget(
                                                filterText: 'Filme',
                                                filter: HomeFilters.movie,
                                              ),
                                              SizedBox(width: 15.0),
                                              HomeFilterWidget(
                                                filterText: 'Séries',
                                                filter: HomeFilters.series,
                                              ),
                                              SizedBox(width: 15.0),
                                              HomeFilterWidget(
                                                filterText: 'Livros',
                                                filter: HomeFilters.book,
                                              ),
                                              SizedBox(width: 15.0),
                                              HomeFilterWidget(
                                                filterText: 'Jogos',
                                                filter: HomeFilters.game,
                                              ),
                                            ],
                                          ),
                                    ),
                                    const SizedBox(height: 10),
                                    if (state.isLoading)
                                      ConstrainedBox(
                                        constraints: constraints,
                                        child: const Center(
                                          child: CircularProgressIndicator(
                                            color: Colors.white,
                                          ),
                                        ),
                                      ),
                                    if (state.recommendedWorks != null && state.recommendedWorks!.isNotEmpty)
                                      WorkPreview(
                                        title: 'Para Você',
                                        works: state.recommendedWorks,
                                        isLoading: state.isLoading,
                                      ),
                                    WorkPreview(
                                      title: 'Populares',
                                      works: state.famousWorks,
                                      isLoading: state.isLoading,
                                    ),
                                    if (state.worksByTags != null) ...state.worksByTags!.entries
                                        .map<Widget>((entry) => entry.value.length > 4 ? WorkPreview(
                                              title: entry.key,
                                              works: entry.value,
                                              isLoading: state.isLoading,
                                            ) : Container())
                                        .toList(),
                                  ],
                                ),
                              );
                          }
                        },
                      ),
                    ],
                  ),
                );
              },
            ),
          ),
        ],
      ),
    );
  }
}
