import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/blocs/session/session_bloc.dart';
import 'package:tcc_app/blocs/session/session_event.dart';
import 'package:tcc_app/blocs/session/session_state.dart';
import 'package:tcc_app/screens/routes.dart';

class HomeDrawer extends StatelessWidget {
  const HomeDrawer({
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<SessionBloc, SessionState>(
      builder: (context, state) {
        if (state is! NoSessionState) {
          return Drawer(
            backgroundColor: const Color(0xFF0E0F1E),
            child: SafeArea(
              child: Padding(
                padding: const EdgeInsets.only(top: 32, left: 20, right: 20, bottom: 20),
                child: Column(
                  children: [
                    GestureDetector(
                      behavior: HitTestBehavior.translucent,
                      onTap: () => Navigator.pushNamed(context, profileScreenRoute),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          CircleAvatar(
                            backgroundColor: Colors.grey,
                            radius: 33.0,
                            backgroundImage: (state as SessionReadyState).userProfile.photo != null ? MemoryImage(state.userProfile.photo!) : null,
                            child: state.userProfile.photo == null
                                ? const Icon(
                                    Icons.person,
                                    size: 50,
                                  )
                                : null,
                          ),
                          Text(
                            state.userProfile.username,
                            style: const TextStyle(
                              fontWeight: FontWeight.bold,
                              fontSize: 22,
                            ),
                          ),
                        ],
                      ),
                    ),
                    const Divider(
                      height: 30,
                      color: Colors.grey,
                    ),
                    const ListTile(
                      leading: Icon(Icons.home_rounded, size: 35),
                      title: Text(
                        'Home',
                        style: TextStyle(
                          fontWeight: FontWeight.bold,
                          fontSize: 22,
                        ),
                      ),
                    ),
                    const Divider(
                      color: Colors.grey,
                    ),
                    ListTile(
                      onTap: () => Navigator.pushNamed(context, personalListScreenRoute),
                      leading: const Icon(Icons.list_alt_rounded, size: 35),
                      title: const Text(
                        'Minha Lista',
                        style: TextStyle(
                          fontWeight: FontWeight.bold,
                          fontSize: 22,
                        ),
                      ),
                    ),
                    const Spacer(),
                    const Divider(
                      color: Colors.grey,
                    ),
                    ListTile(
                      onTap: () {
                        context.read<SessionBloc>().add(SessionRevokeAccessEvent());

                        Navigator.pushReplacementNamed(
                          context,
                          loginScreenRoute,
                        );
                      },
                      leading: const Icon(Icons.exit_to_app, size: 35),
                      title: const Text(
                        'Sair',
                        style: TextStyle(
                          fontWeight: FontWeight.bold,
                          fontSize: 22,
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          );
        }
        return Container();
      },
    );
  }
}
