import 'package:flutter/material.dart';
import 'package:tcc_app/screens/routes.dart';
import 'package:tcc_app/view_model/work_view_model.dart';
import 'package:tcc_app/widgets/work_card.dart';

class WorkPreview extends StatelessWidget {
  final String? title;
  final List<WorkViewModel>? works;
  final bool isLoading;

  const WorkPreview(
      {required this.title,
      required this.works,
      this.isLoading = false,
      Key? key})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return works != null && works!.isNotEmpty && !isLoading
        ? Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 18.0),
              child: Text(
                title!,
                style: const TextStyle(
                  fontSize: 24.0,
                  fontWeight: FontWeight.bold,
                  color: Colors.white,
                ),
              ),
            ),
            SizedBox(
              height: 160.0,
              child: ListView.builder(
                scrollDirection: Axis.horizontal,
                padding:
                    const EdgeInsets.symmetric(horizontal: 10, vertical: 10),
                physics: const BouncingScrollPhysics(),
                itemCount: works!.length,
                itemBuilder: (context, index) {
                  final WorkViewModel work = works![index];

                  return InkWell(
                    onTap: () {
                      Navigator.pushNamed(context, workScreenRoute,
                          arguments: work.workId);
                    },
                    child: WorkCard(coverUrl: work.coverUrl!, name: work.name),
                  );
                },
              ),
            ),
            const SizedBox(height: 10.0)
          ])
        : Container();
  }
}
