import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/blocs/session/session_bloc.dart';
import 'package:tcc_app/blocs/session/session_event.dart';
import 'package:tcc_app/blocs/session/session_state.dart';
import 'package:tcc_app/screens/login/widgets/login_container.dart';
import 'package:tcc_app/screens/routes.dart';
import 'package:tcc_app/widgets/main_button.dart';
import 'package:tcc_app/widgets/text_form_input.dart';
import 'package:tcc_app/widgets/underlined_clickable_text.dart';

class LoginScreen extends StatelessWidget {
  final _form = GlobalKey<FormState>();

  LoginScreen({Key? key}) : super(key: key);

  final TextEditingController usernameController = TextEditingController();
  final TextEditingController passwordController = TextEditingController();

  void _save(BuildContext context) {
    if (!_form.currentState!.validate()) return;
    context.read<SessionBloc>().add(SessionAuthEvent(
          username: usernameController.text,
          password: passwordController.text,
        ));
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: const Color(0xFF254176),
      body: SafeArea(
          child: Container(
        alignment: Alignment.center,
        height: double.infinity,
        decoration: const BoxDecoration(
          image: DecorationImage(
            image: AssetImage(
              'assets/images/background_image.png',
            ),
            fit: BoxFit.fill,
          ),
        ),
        child: BlocConsumer<SessionBloc, SessionState>(
          listener: ((context, state) {
            switch (state.runtimeType) {
              case SessionErrorState:
                break;
              case SessionReadyState:
                Navigator.pushReplacementNamed(context, homeScreenRoute);
                break;
              default:
            }
          }),
          builder: (context, state) {
            if (state is SessionLoadingState ||state is SessionReadyState) {
              return const Center(child: CircularProgressIndicator());
            }

            return SingleChildScrollView(
              physics: const BouncingScrollPhysics(),
              child: Column(
                children: [
                  LoginContainer(
                    child: Form(
                      key: _form,
                      child: Column(
                        children: [
                          const Center(
                              child: Text(
                            'PAIMON',
                            style: TextStyle(color: Colors.white, fontSize: 45),
                          )),
                          const SizedBox(height: 15.0),
                          if (state is SessionErrorState)
                            Padding(
                              padding: const EdgeInsets.only(bottom: 24.0),
                              child: Text(state.errorMessage ?? '',
                                  style: const TextStyle(
                                      color: Color(0xFFC02222))),
                            ),
                          TextFormInput(
                            controller: usernameController,
                            enabled: state is! LoggingUserInState,
                            hintText: 'usuário',
                            validator: (String? value) {
                              if (value == null || value == "") {
                                return 'Preencha o usuário';
                              }
                              return null;
                            },
                          ),
                          const SizedBox(height: 40.0),
                          TextFormInput(
                            controller: passwordController,
                            enabled: state is! LoggingUserInState,
                            hintText: 'senha',
                            obscureText: true,
                            validator: (String? value) {
                              if (value == null || value == "") {
                                return 'Preencha a senha';
                              }
                              return null;
                            },
                          ),
                          const SizedBox(height: 50.0),
                          MainButton(
                            loading: state is LoggingUserInState,
                            child: const Text(
                              'Entrar',
                              style: TextStyle(
                                color: Colors.white,
                                fontWeight: FontWeight.bold,
                                fontSize: 20.0,
                                letterSpacing: 2,
                              ),
                            ),
                            onTap: () => _save(context),
                          ),
                          const SizedBox(height: 25.0),
                          Align(
                            alignment: Alignment.bottomRight,
                            child: UnderlinedClickableText(
                              text: 'Cadastre-se',
                              onTap: () => Navigator.pushNamed(
                                context,
                                registerScreenRoute,
                              ),
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                ],
              ),
            );
          },
        ),
      )),
    );
  }
}
