import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/data/dtos/read_person_dto.dart';
import 'package:tcc_app/services/person_service.dart';

part 'person_event.dart';
part 'person_state.dart';

class PersonBloc extends Bloc<PersonEvent, PersonState> {
  final PersonService personService;

  PersonBloc({required this.personService}) : super(const InitialPersonState()) {
    on<LoadPersonEvent>((event, emit) => _loadPersonByName(event.personName, emit));
  }

  Future<void> _loadPersonByName(String personName, Emitter<PersonState> emit) async {
    emit(const LoadingPersonState());
    try {
      final person = await personService.findByPersonName(personName);
      if (person == null) {
        emit(NotFoundPersonState(personName));
      } else {
        emit(SuccessPersonState(person));
      }
    } on Exception catch (e) {
      emit(ErrorPersonState(e.toString()));
    }
  }
}