import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/screens/person/widget/person_widget.dart';

import 'bloc/person_bloc.dart';

class PersonScreen extends StatelessWidget {
  const PersonScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final personName = ModalRoute.of(context)!.settings.arguments as String?;
    return BlocBuilder<PersonBloc, PersonState>(
      builder: (context, state) {
        Widget widget;
        String title = '...';
        if (state is InitialPersonState && personName != null) {
          context.read<PersonBloc>().add(LoadPersonEvent(personName));
        }
        if (state is SuccessPersonState) {
          title = state.person.name;
          widget = PersonWidget(state.person);
        } else if (state is LoadingPersonState || state is InitialPersonState) {
          widget = Container(alignment: AlignmentDirectional.center, child: const CircularProgressIndicator());
        } else {
          widget = Container();
        }

        return Scaffold(
          appBar: AppBar(
            title: Text(title.toUpperCase()),
            leading: IconButton(
              onPressed: () => Navigator.pop(context),
              icon: const Icon(Icons.chevron_left_rounded, size: 45),
            ),
            centerTitle: true,
            backgroundColor: Colors.black26,
          ),
          body: widget,
        );
      },
    );
  }
}
