import 'package:flutter/material.dart';
import 'package:optimized_cached_image/optimized_cached_image.dart';
import 'package:tcc_app/data/dtos/read_person_dto.dart';
import 'package:tcc_app/widgets/work_card.dart';

import '../../routes.dart';

class PersonWidget extends StatelessWidget {
  final ReadPersonDto person;

  const PersonWidget(this.person, {Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      physics: const BouncingScrollPhysics(),
      child: Column(
        children: [
          Row(
            children: [
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: OptimizedCacheImage(
                  imageUrl: person.photo,
                  height: 150,
                ),
              ),
              Expanded(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text(
                      person.name,
                      textAlign: TextAlign.start,
                      style: const TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 24,
                      ),
                    ),
                    if (person.birthDate != null) Text(person.birthDate!.split('-').first, style: const TextStyle(fontSize: 16)),
                  ],
                ),
              ),
            ],
          ),
          if (person.biography != null)
            Padding(
              padding: const EdgeInsets.symmetric(horizontal: 16, vertical: 12),
              child: Text(person.biography!, textAlign: TextAlign.justify),
            ),
          const Padding(
            padding: EdgeInsets.symmetric(vertical: 8.0, horizontal: 16),
            child: Divider(
              height: 2,
              color: Colors.white54,
            ),
          ),
          if (person.workedOn != null && person.workedOn!.isNotEmpty)
            GridView.builder(
              itemCount: person.workedOn!.length,
              scrollDirection: Axis.vertical,
              shrinkWrap: true,
              gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
              itemBuilder: (content, index) {
                final work = person.workedOn![index];
                return GestureDetector(
                  onTap: () => Navigator.pushNamed(context, workScreenRoute, arguments: work.work.id),
                  child: WorkCard(name: work.work.name, coverUrl: work.work.cover, height: 120,),
                );
              },
            ),
            const SizedBox(height: 12.0)
        ],
      ),
    );
  }
}
