import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/data/dtos/work_in_personal_list_dto.dart';
import 'package:tcc_app/exceptions/app_exception.dart';
import 'package:tcc_app/services/auth_service.dart';
import 'package:tcc_app/services/work_service.dart';

part 'personal_list_event.dart';

part 'personal_list_state.dart';

class PersonalListBloc extends Bloc<PersonalListEvent, PersonalListState> {
  final AuthService authService;
  final WorkService workService;

  PersonalListBloc({required this.authService, required this.workService}) : super(const InitialPersonalListState()) {
    on<LoadPersonalListEvent>((event, emit) => _loadPersonalList(emit));
  }

  Future<void> _loadPersonalList(Emitter<PersonalListState> emit) async {
    emit(const LoadingPersonalListState());
    final currentUser = await authService.getCurrentUser();

    if (currentUser == null) {
      emit(const NotLoggedPersonalListState());
      return;
    }

    try {
      final workList = await workService.getUserPersonalList(currentUser);
      if (workList == null) {
        emit(const ErrorPersonalListState('Erro ao consultar a lista pessoal'));
      } else if (workList.isEmpty) {
        emit(const EmptyPersonalListState());
      } else {
        emit(SuccessPersonalListState(workList));
      }
    } on AppException catch (e) {
      emit(ErrorPersonalListState(e.message));
    }
  }
}
