import 'package:flutter/material.dart';
import 'package:tcc_app/data/dtos/work_in_personal_list_dto.dart';
import 'package:tcc_app/i18n_consts.dart';
import 'package:tcc_app/screens/routes.dart';
import 'package:tcc_app/widgets/star_rating.dart';
import 'package:tcc_app/widgets/work_card.dart';

class PersonalGrid extends StatelessWidget {
  final List<WorkInPersonalListDto> works;

  const PersonalGrid({required this.works, Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      scrollDirection: Axis.vertical,
      physics: const BouncingScrollPhysics(),
      shrinkWrap: true,
      padding: const EdgeInsets.symmetric(vertical: 6, horizontal: 8),
      gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
        crossAxisCount: 3,
        mainAxisExtent: 180,
        mainAxisSpacing: 10,
        crossAxisSpacing: 10,
        childAspectRatio: 1.0,
      ),
      itemCount: works.length,
      itemBuilder: (BuildContext ctx, int index) {
        final WorkInPersonalListDto work = works[index];
        return InkWell(
          onTap: () => Navigator.pushNamed(
            context,
            workScreenRoute,
            arguments: work.work.id,
          ),
          child: Stack(
            alignment: Alignment.bottomCenter,
            fit: StackFit.expand,
            children: [
              Container(
                decoration: const BoxDecoration(
                  borderRadius: BorderRadius.all(Radius.circular(5)),
                  color: Colors.black26,
                ),
              ),
              WorkCard(
                coverUrl: work.work.cover,
                name: work.work.name,
                fit: BoxFit.cover,
                height: 180,
                width: 120,
                margin: EdgeInsets.zero
              ),
              Container(
                alignment: Alignment.topCenter,
                height: 60,
                padding: EdgeInsets.symmetric(vertical: 8.0, horizontal: 3.0),
                constraints: const BoxConstraints(maxHeight: 60),
                decoration: BoxDecoration(
                  borderRadius: const BorderRadius.all(Radius.circular(5)),
                  gradient: LinearGradient(
                    colors: [
                      Colors.black,
                      Colors.black.withOpacity(0.7),
                      Colors.transparent,
                    ],
                    stops: const [0, 0.5,  0.8],
                    begin: Alignment.topCenter,
                    end: Alignment.center,
                  ),
                ),
                child: Text(
                  work.work.name,
                  textAlign: TextAlign.center,
                  maxLines: 2,
                  overflow: TextOverflow.ellipsis,
                  style: const TextStyle(
                    fontSize: 16,
                    fontWeight: FontWeight.bold,
                  ),
                ),
              ),
              Container(
                alignment: Alignment.bottomCenter,
                decoration: BoxDecoration(
                  borderRadius: const BorderRadius.all(Radius.circular(5)),
                  gradient: LinearGradient(
                    colors: [
                      Colors.black,
                      Colors.black.withOpacity(0.7),
                      Colors.black26,
                      Colors.transparent,
                    ],
                    stops: const [0, 0.4, 0.5, 0.7],
                    begin: Alignment.bottomCenter,
                    end: Alignment.center,
                  ),
                ),
                child: Padding(
                  padding: const EdgeInsets.symmetric(vertical: 8.0),
                  child: Column(
                    mainAxisSize: MainAxisSize.max,
                    mainAxisAlignment: MainAxisAlignment.end,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      Text(
                        (statusName[work.status] ?? work.status).toUpperCase(),
                        textAlign: TextAlign.center,
                        style: const TextStyle(
                          fontSize: 12,
                        ),
                      ),
                      if (work.status != 'planning' && work.score > 0)
                        StarRating(work.score.toDouble())
                      else SizedBox(height: 8)
                    ],
                  ),
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}
