import 'package:flutter/material.dart';
import 'package:tcc_app/data/dtos/work_in_personal_list_dto.dart';
import 'package:tcc_app/i18n_consts.dart';
import 'package:tcc_app/screens/routes.dart';
import 'package:tcc_app/widgets/star_rating.dart';

class PersonalLines extends StatelessWidget {
  final List<WorkInPersonalListDto> works;

  const PersonalLines({required this.works, Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ListView.separated(
      itemCount: works.length,
      shrinkWrap: true,
      scrollDirection: Axis.vertical,
      physics: const BouncingScrollPhysics(),
      separatorBuilder: (ctx, index) => const Divider(),
      itemBuilder: (BuildContext ctx, int index) {
        final work = works[index];
        return InkWell(
          onTap: () => Navigator.pushNamed(context, workScreenRoute, arguments: work.work.id), 
          child: Row(
            mainAxisSize: MainAxisSize.max,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Flexible(
                flex: 1,
                child: Padding(
                  padding:
                      const EdgeInsets.symmetric(vertical: 4, horizontal: 12),
                  child: Image.network(
                    work.work.cover,
                    height: 110,
                    fit: BoxFit.cover,
                  ),
                ),
              ),
              Flexible(
                flex: 3,
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    Padding(
                      padding: const EdgeInsets.symmetric(vertical: 4.0),
                      child: Text(
                        work.work.name,
                        textAlign: TextAlign.start,
                        style: const TextStyle(
                            fontWeight: FontWeight.bold, fontSize: 16),
                      ),
                    ),
                    Text(work.work.releaseYear.toString()),
                    Padding(
                      padding: const EdgeInsets.symmetric(vertical: 12.0),
                      child: Text("Status: ${statusName[work.status]}"),
                    ),
                    Align(
                      alignment: Alignment.bottomLeft,
                      heightFactor: 1.5,
                      child: StarRating(work.score.toDouble()),
                    ),
                  ],
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}
