import 'package:flutter/widgets.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/data/dtos/work_status_with_details_dto.dart';
import 'package:tcc_app/data/dtos/work_user_status_dto.dart';
import 'package:tcc_app/exceptions/app_exception.dart';
import 'package:tcc_app/services/auth_service.dart';
import 'package:tcc_app/services/work_service.dart';

part 'personal_work_status_event.dart';

part 'personal_work_status_state.dart';

class PersonalWorkStatusBloc
    extends Bloc<PersonalWorkStatusEvent, PersonalWorkStatusState> {
  final AuthService authService;
  final WorkService workService;

  PersonalWorkStatusBloc({required this.authService, required this.workService})
      : super(const InitialPersonalWorkStatusState()) {
    on<LoadPersonalWorkStatusEvent>(
        (event, emit) => _loadPersonalWorkStatus(emit, event.workId));
    on<UpdateScreenPersonalWorkStatusEvent>(
        (event, emit) => event.setScreenState());
    on<SavePersonalWorkStatusEvent>((event, emit) => _savePersonalWorkStatus(
        emit, event.currentState, event.workId, event.work, event.callback));
  }

  Future<void> _loadPersonalWorkStatus(
      Emitter<PersonalWorkStatusState> emit, String workId) async {
    emit(const LoadingPersonalWorkStatusState());

    final currentUser = await authService.getCurrentUser();

    if (currentUser == null) {
      emit(const NotLoggedPersonalWorkStatusState());
      return;
    }

    try {
      final workDetails = await workService.findById(workId);
      if (workDetails == null) {
        emit(const ErrorPersonalWorkStatusState(
            'Erro ao buscar os detalhes da obra'));
        return;
      }
      var workOrNull =
          await workService.getUserPersonalWorkStatus(currentUser, workId);
      var work = workOrNull ?? WorkUserStatusDto(status: '', score: 1, progress: null);
      emit(SuccessPersonalWorkStatusState(
        work: WorkStatusWithDetailsDto.fromStatusAndDetails(
          work,
          workDetails,
        ),
      ));
    } on AppException catch (e) {
      emit(ErrorPersonalWorkStatusState(e.message));
    }
  }

  Future<void> _savePersonalWorkStatus(
      Emitter<PersonalWorkStatusState> emit,
      SuccessPersonalWorkStatusState currentState,
      String workId,
      WorkUserStatusDto work,
      void Function(bool) callback) async {
    emit(const LoadingPersonalWorkStatusState());
    final currentUser = (await authService.getCurrentUser())!;

    try {
      final result = await workService.addOrUpdatePersonalWorkStatus(currentUser, workId, work);
      callback(result);
      if (!result) emit(currentState);
    } catch (_) {
      callback(false);
      emit(currentState);
    }
  }
}
