import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/data/dtos/statistics_model_dto.dart';
import 'package:tcc_app/screens/profile/bloc/profile_bloc.dart';
import 'package:tcc_app/screens/profile/widgets/statistics_card.dart';
import 'package:tcc_app/screens/routes.dart';
import 'package:tcc_app/widgets/blur_container.dart';
import 'package:tcc_app/widgets/main_button.dart';

class ProfilePage extends StatelessWidget {
  const ProfilePage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: BlocBuilder<ProfileBloc, ProfileState>(
        builder: (context, state) {
          if (state is ProfileLoadingState) {
            return const Center(child: CircularProgressIndicator());
          }
          return SingleChildScrollView(
            physics: const BouncingScrollPhysics(),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Stack(
                  clipBehavior: Clip.none,
                  alignment: Alignment.center,
                  children: [
                    Container(
                      height: 270,
                      padding: EdgeInsets.only(
                          top: MediaQuery.of(context).padding.top),
                      decoration: BoxDecoration(
                        image: DecorationImage(
                          image: NetworkImage((state as ProfileReadyState)
                              .userProfile
                              .profileCover),
                          fit: BoxFit.cover,
                        ),
                      ),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: Container(
                              height: 50,
                              width: 50,
                              decoration: BoxDecoration(
                                  color: Colors.black26,
                                  borderRadius: BorderRadius.circular(50),
                              ),
                              child: IconButton(
                                onPressed: () => Navigator.pop(context),
                                icon: const Icon(Icons.chevron_left_rounded,
                                    size: 32),
                              ),
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.only(
                              top: 10.0,
                              right: 20.0,
                            ),
                            child: TextButton(
                              style: TextButton.styleFrom(
                                backgroundColor: Colors.black87,
                                padding: const EdgeInsets.symmetric(
                                    horizontal: 12, vertical: 8),
                                shape: const RoundedRectangleBorder(
                                  borderRadius: BorderRadius.all(
                                    Radius.circular(16.0),
                                  ),
                                ),
                              ),
                              clipBehavior: Clip.antiAlias,
                              onPressed: () => Navigator.pushNamed(
                                context,
                                profileEditScreenRoute,
                                arguments: state.userProfile,
                              ),
                              child: const ContainerBlur(
                                child: Text(
                                  'Editar  perfil',
                                  style: TextStyle(
                                      fontSize: 14.0,
                                      fontWeight: FontWeight.bold),
                                ),
                              ),
                            ),
                          )
                        ],
                      ),
                    ),
                    Positioned(
                      bottom: -55,
                      child: Container(
                        height: 115,
                        width: 115,
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          color: Colors.grey,
                          image: state.userProfile.photo != null
                              ? DecorationImage(
                                  image: MemoryImage(state.userProfile.photo!),
                                  fit: BoxFit.cover,
                                )
                              : null,
                        ),
                        child: state.userProfile.photo == null
                            ? const Icon(
                                Icons.person,
                                size: 50,
                              )
                            : null,
                      ),
                    ),
                  ],
                ),
                const SizedBox(height: 55),
                Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 15),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    crossAxisAlignment: CrossAxisAlignment.end,
                    children: [
                      Text(
                        state.userProfile.name,
                        style: const TextStyle(
                            fontSize: 24, fontWeight: FontWeight.bold),
                      ),
                      Text(
                        '@${state.userProfile.username}',
                        style: const TextStyle(fontSize: 18),
                      )
                    ],
                  ),
                ),
                const SizedBox(height: 23),
                Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 13),
                  child: MainButton(
                    onTap: () =>
                        Navigator.pushNamed(context, personalListScreenRoute),
                    child: const Text(
                      'Minha lista',
                      style: TextStyle(
                        color: Colors.white,
                        fontWeight: FontWeight.bold,
                        fontSize: 16,
                      ),
                    ),
                  ),
                ),
                const SizedBox(height: 20),
                const Padding(
                  padding: EdgeInsets.symmetric(horizontal: 15),
                  child: Divider(),
                ),
                const SizedBox(height: 20),
                if (state.userProfile.statistics.isNotEmpty) const Padding(
                  padding: EdgeInsets.symmetric(horizontal: 15),
                  child: Text(
                    'Estatísticas',
                    style: TextStyle(fontSize: 24, fontWeight: FontWeight.bold),
                  ),
                ),
                if (state.userProfile.statistics.isNotEmpty) ...state.userProfile.statistics
                    .map<Widget>((s) => StatisticsCard(statusValue: s))
                    .toList(),
                SizedBox(height: MediaQuery.of(context).padding.bottom + 15)
              ],
            ),
          );
        },
      ),
    );
  }
}
