import 'package:flutter/material.dart';
import 'package:tcc_app/screens/profile/widgets/statistics_card.dart';

class GraphicsPainter extends CustomPainter {
  final int completed;
  final int onhold;
  final int ongoing;
  final int planning;
  final int dropped;
  final double height = 21;

  GraphicsPainter({
    required this.completed,
    required this.onhold,
    required this.ongoing,
    required this.planning,
    required this.dropped,
  });

  @override
  void paint(Canvas canvas, Size size) {
    final int total = planning + ongoing + onhold + completed + dropped;

    final double planningCent = planning / total;
    final double onholdCent = onhold / total;
    final double ongoingCent = ongoing / total;
    final double completedCent = completed / total;
    final double droppedCent = dropped / total;

    final double constant = 16;

    double startAt = 0;

    final completedPaint = Paint()
      ..color = const Color(StatisticsCard.completed)
      ..style = PaintingStyle.fill;

    final onholdPaint = Paint()
      ..color = const Color(StatisticsCard.onhold)
      ..style = PaintingStyle.fill;

    final planningPaint = Paint()
      ..color = const Color(StatisticsCard.planning)
      ..style = PaintingStyle.fill;

    final ongoingPaint = Paint()
      ..color = const Color(StatisticsCard.ongoing)
      ..style = PaintingStyle.fill;

    final droppedPaint = Paint()
      ..color = const Color(StatisticsCard.dropped)
      ..style = PaintingStyle.fill;

    canvas.drawRRect(
      RRect.fromRectAndRadius(
        Rect.fromLTWH(0, 0, size.width, size.height),
        Radius.circular(constant),
      ),
      planningPaint,
    );

    canvas.drawRRect(
      RRect.fromRectAndRadius(
        Rect.fromLTWH(
          0,
          0,
          (size.width * completedCent) +
              (size.width * ongoingCent) +
              (size.width * onholdCent)+
              (size.width * droppedCent),
          size.height,
        ),
        Radius.circular(constant),
      ),
      droppedPaint,
    );
    canvas.drawRRect(
      RRect.fromRectAndRadius(
        Rect.fromLTWH(
          0,
          0,
          (size.width * completedCent) +
              (size.width * ongoingCent) +
              (size.width * onholdCent),
          size.height,
        ),
        Radius.circular(constant),
      ),
      onholdPaint,
    );
    canvas.drawRRect(
      RRect.fromRectAndRadius(
        Rect.fromLTWH(
          0,
          0,
          (size.width * completedCent) + (size.width * ongoingCent),
          size.height,
        ),
        Radius.circular(constant),
      ),
      ongoingPaint,
    );

    canvas.drawRRect(
      RRect.fromRectAndRadius(
        Rect.fromLTWH(0, 0, size.width * completedCent, size.height),
        Radius.circular(constant),
      ),
      completedPaint,
    );

    // totalCent = totalCent * (1 - ongoingCent);
  }

  @override
  bool shouldRepaint(covariant CustomPainter oldDelegate) => false;
}
