import 'package:flutter/material.dart';
import 'package:tcc_app/data/dtos/statistics_model_dto.dart';
import 'package:tcc_app/helpers/string.dart';
import 'package:tcc_app/screens/profile/widgets/custom_graphics_painter.dart';
import 'package:tcc_app/screens/profile/widgets/status_widget.dart';

class StatisticsCard extends StatelessWidget {
  final StatisticsDto statusValue;

  static const int completed = 0XFF31612C;
  static const int onhold = 0XFFA48F22;
  static const int ongoing = 0XFF2275A4;
  static const int planning = 0X44FFFFFF;
  static const int dropped = 0XFF8B111E;

  const StatisticsCard({
    required this.statusValue,
  });

  @override
  Widget build(BuildContext context) {
    return  
    statusValue.completedNum == 0 && statusValue.onholdNum == 0 &&
    statusValue.ongoingNum == 0 && statusValue.planningNum == 0 ?
    Container() : 
    Container(
      padding: const EdgeInsets.symmetric(
        horizontal: 17,
        vertical: 8,
      ),
      margin: const EdgeInsets.only(right: 15.0, left: 15.0, top: 13),
      decoration: BoxDecoration(
          color: Colors.white12, borderRadius: BorderRadius.circular(7.0)),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(
            translateWorkType(workType: statusValue.type),
            style: const TextStyle(
              fontSize: 22.0,
              fontWeight: FontWeight.bold,
            ),
          ),
          const SizedBox(height: 12),
          ConstrainedBox(
            constraints:
                BoxConstraints.tightFor(height: 21, width: double.infinity),
            child: CustomPaint(
              painter: GraphicsPainter(
                completed: statusValue.completedNum,
                onhold: statusValue.onholdNum,
                ongoing: statusValue.ongoingNum,
                planning: statusValue.planningNum,
                dropped: statusValue.droppedNum
              ),
            ),
          ),
          const SizedBox(height: 12),
          Wrap(
            runSpacing: 10,
            spacing: 20,
            children: [
              StatusWidget(
                title: statusValue.completed ?? '',
                value: statusValue.completedNum,
                color: const Color(completed),
              ),
              StatusWidget(
                title: statusValue.ongoing ?? '',
                value: statusValue.ongoingNum,
                color: const Color(ongoing),
              ),
              StatusWidget(
                title: statusValue.onhold ?? '',
                value: statusValue.onholdNum,
                color: const Color(onhold),
              ),
              StatusWidget(
                title: statusValue.dropped ?? '',
                value: statusValue.droppedNum,
                color: const Color(dropped),
              ),
              StatusWidget(
                title: statusValue.planning ?? '',
                value: statusValue.planningNum,
                color: const Color(planning),
              ),
            ],
          ),
          const SizedBox(height: 12.0),
          const Divider(),
          const SizedBox(height: 12.0),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text('Nota Geral:',
                  style: TextStyle(
                    fontSize: 16,
                  )),
              Text('⭐ ${statusValue.averageScore.toStringAsFixed(1)}/5'),
            ],
          ),
        ],
      ),
    );
  }
}
