import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/blocs/session/session_bloc.dart';
import 'package:tcc_app/blocs/user/user_bloc.dart';
import 'package:tcc_app/data/dtos/profile_dto.dart';
import 'package:tcc_app/screens/edit_profile/bloc/edit_profile_bloc.dart';
import 'package:tcc_app/screens/edit_profile/edit_profile.dart';
import 'package:tcc_app/screens/home/bloc/home_bloc.dart';
import 'package:tcc_app/screens/home/home_screen.dart';
import 'package:tcc_app/screens/login/login_screen.dart';
import 'package:tcc_app/screens/person/bloc/person_bloc.dart';
import 'package:tcc_app/screens/person/person_screen.dart';
import 'package:tcc_app/screens/profile/bloc/profile_bloc.dart';
import 'package:tcc_app/screens/profile/profile_page.dart';
import 'package:tcc_app/screens/personal_list/bloc/personal_list_bloc.dart';
import 'package:tcc_app/screens/personal_list/personal_list_screen.dart';
import 'package:tcc_app/screens/register/register_screen.dart';
import 'package:tcc_app/screens/search/bloc/search_bloc.dart';
import 'package:tcc_app/screens/work/bloc/work_bloc.dart';
import 'package:tcc_app/screens/work/work_screen.dart';
import 'package:tcc_app/screens/search/search_page.dart';
import 'package:tcc_app/services/auth_service.dart';
import 'package:tcc_app/services/person_service.dart';
import 'package:tcc_app/services/user_service.dart';
import 'package:tcc_app/services/work_service.dart';

const String loginScreenRoute = '/login_screen';
const String registerScreenRoute = '/register-screen';
const String homeScreenRoute = '/home-screen';
const String workScreenRoute = '/work-screen';
const String personScreenRoute = '/person-screen';
const String searchScreenRoute = '/search';
const String profileScreenRoute = '/profile';
const String profileEditScreenRoute = '/profile-edit';
const String personalListScreenRoute = '/personal-list';

Map<String, Widget Function(BuildContext)> routes = {
  loginScreenRoute: (context) => LoginScreen(),
  registerScreenRoute: (context) => const RegisterScreen(),
  homeScreenRoute: (context) => BlocProvider(
        create: (context) => HomeBloc(workService: WorkService.instance),
        child: const HomeScreen(),
      ),
  workScreenRoute: (context) => BlocProvider(
        create: (ctx) => WorkBloc(workService: WorkService.instance, authService: AuthService.instance),
        child: const WorkScreen(),
      ),
  personScreenRoute: (context) => BlocProvider(
        create: (ctx) => PersonBloc(personService: PersonService.instance),
        child: const PersonScreen(),
      ),
  searchScreenRoute: (context) => BlocProvider(
        create: (context) => SearchBloc(
          workService: WorkService.instance,
          authService: AuthService.instance,
        ),
        child: SearchPage(),
      ),
  profileScreenRoute: (context) => BlocProvider(
        create: (context) => ProfileBloc(
          userService: UserService.instance,
          username: context.read<SessionBloc>().state.username ?? '',
        ),
        child: const ProfilePage(),
      ),
  personalListScreenRoute: (context) => BlocProvider(
        create: (ctx) => PersonalListBloc(
          authService: AuthService.instance,
          workService: WorkService.instance,
        ),
        child: const PersonalListScreen(),
      ),
  profileEditScreenRoute: (context) => BlocProvider(
        create: (ctx) => EditProfileBloc(
          userService: UserService.instance,
          workService: WorkService.instance,
          userProfile: ModalRoute.of(context)?.settings.arguments as ProfileDto?,
        ),
        child: EditProfile(),
      ),
};
