import 'package:flutter_bloc/flutter_bloc.dart';

import '../../../data/dtos/read_work_details_dto.dart';
import '../../../data/dtos/work_in_personal_list_dto.dart';
import '../../../services/auth_service.dart';
import '../../../services/work_service.dart';

part 'search_event.dart';

part 'search_state.dart';

class SearchBloc extends Bloc<SearchEvent, SearchState> {
  final WorkService workService;
  final AuthService authService;

  SearchBloc({required this.workService, required this.authService}) : super(SearchState(works: null, query: '')) {
    on<StartSearchEvent>((_, emit) => _loadUserList(emit));
    on<ChangeSearchFilterEvent>((event, emit) => _changeFilter(event, emit));
    on<SearchEvent>((event, emit) => _searchWork(event, emit));
    add(StartSearchEvent());
  }

  void _loadUserList(Emitter<SearchState> emit) async {
    try {
      final username = await authService.getCurrentUser();
      final userList = await workService.getUserPersonalList(username ?? '');
      if (userList?.isNotEmpty ?? false) {
        emit(state.copyWith(userList: userList!));
      }
    } finally {}
  }

  void _searchWork(SearchEvent event, Emitter<SearchState> emit) async {
    try {
      emit(state.copyWith(isLoading: true, query: event.query!));
      final List<ReadWorkDetailsDto>? works = await workService.searchWork(query: event.query!, type: state.type);

      emit(state.copyWith(works: works));
    } catch (e) {
      emit(state.copyWith(works: null));
    } finally {
      emit(state.copyWith(isLoading: false));
    }
  }

  void _changeFilter(ChangeSearchFilterEvent event, Emitter<SearchState> emit) async {
    try {
      emit(state.copyWith(isLoading: true, type: event.filter));

      if (state.query.isNotEmpty) {
        final List<ReadWorkDetailsDto>? works = await workService.searchWork(query: state.query, type: state.type);

        emit(state.copyWith(works: works));
      }
    } catch (e) {
      emit(state.copyWith(works: null));
    } finally {
      emit(state.copyWith(isLoading: false));
    }
  }
}
