import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/data/dtos/read_work_details_dto.dart';
import 'package:tcc_app/screens/search/bloc/search_bloc.dart';
import 'package:tcc_app/screens/search/widgets/search_filter_widget.dart';
import 'package:tcc_app/screens/search/widgets/search_item_widget.dart';

class SearchPage extends StatelessWidget {
  SearchPage({Key? key}) : super(key: key);

  final TextEditingController _controller = TextEditingController();
  final FocusNode _focusNode = FocusNode()..requestFocus();
  Timer? debounce;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: const Color(0xFF203C6D),
      appBar: AppBar(
        centerTitle: true,
        backgroundColor: const Color(0xFF203C6D),
        elevation: 2.5,
        leading: IconButton(
          icon: const Icon(Icons.chevron_left_rounded, size: 40),
          onPressed: () => Navigator.pop(context),
        ),
        actions: const [
          TodosOverviewFilterButton(),
        ],
        title: Padding(
          padding: const EdgeInsets.only(right: 15, top: 5),
          child: TextField(
            controller: _controller,
            focusNode: _focusNode,            
            decoration: InputDecoration(
              isCollapsed: true,
              contentPadding: EdgeInsets.only(bottom: 7),
              hintText: 'Pesquise...'
            ),
            onChanged: (query) { 
              if(debounce != null && debounce!.isActive) debounce?.cancel(); 

              if (query.isNotEmpty) {
                debounce = Timer(
                    Duration(milliseconds: 500),
                    () => context
                        .read<SearchBloc>()
                        .add(SearchEvent(query: query)));
              }
            },
          ),
        ),
      ),
      body: SafeArea(
        child: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 22.0),
          child: BlocBuilder<SearchBloc, SearchState>(
            builder: (context, state) {
              if (state.isLoading) {
                return const Center(child: CircularProgressIndicator());
              }
              if (state.works == null) {
                return const Center(
                    child: Text(
                  'Digite o nome de uma obra para pesquisá-la',
                  style: TextStyle(fontSize: 16.0),
                ));
              }
              return state.works!.isNotEmpty
                  ? ListView.separated(
                    primary: true,
                      keyboardDismissBehavior:
                          ScrollViewKeyboardDismissBehavior.onDrag,
                      physics: const BouncingScrollPhysics(),
                      itemCount: state.works!.length+2,
                      separatorBuilder: (context, index) {
                          if(index == 0 || index ==state.works!.length+1){
                            return const SizedBox(height: 20.0);
                          }

                          return const Divider(height: 20.0);
                          },
                      itemBuilder: (context, index) {
                        if(index == 0 || index == state.works!.length+1) return Container();
                        
                        final ReadWorkDetailsDto work = state.works![index-1];
                        return SearchItemWidget(work: work, isInUserList: state.userList.isNotEmpty && state.userList.any((w) => work.id == w.work.id),);
                      })
                  : const Center(
                      child: Text(
                      'Não há obras correspondentes a sua busca',
                      style: TextStyle(fontSize: 16.0),
                    ));
            },
          ),
        ),
      ),
    );
  }
}
