import 'package:flutter/material.dart';
import 'package:optimized_cached_image/optimized_cached_image.dart';
import 'package:tcc_app/data/dtos/read_work_details_dto.dart';
import 'package:tcc_app/screens/personal_work_status/personal_work_status_modal.dart';

import '../../routes.dart';

class SearchItemWidget extends StatelessWidget {
  final ReadWorkDetailsDto work;
  final bool isInUserList;

  const SearchItemWidget({
    required this.work,
    required this.isInUserList,
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    print(isInUserList);
    return IntrinsicHeight(
      child: Row(children: [
        Container(
          clipBehavior: Clip.hardEdge,
          margin: const EdgeInsets.symmetric(horizontal: 8.0),
          decoration: BoxDecoration(
            color: Colors.grey,
            borderRadius: BorderRadius.circular(5.0),
          ),
          height: 96,
          width: 69,
          child: OptimizedCacheImage(
            height: 96 * 2,
            width: 69 * 2,
            fit: BoxFit.cover,
            imageUrl: work.cover,
            progressIndicatorBuilder: (context, url, downloadProgress) => Center(
              child: SizedBox(
                width: 25.0,
                height: 25.0,
                child: CircularProgressIndicator(value: downloadProgress.progress),
              ),
            ),
            errorWidget: (context, url, error) => const Icon(Icons.image),
          ),
        ),
        const SizedBox(width: 8.0),
        Expanded(
          flex: 5,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Expanded(
                child: Text(
                  work.name,
                  style: const TextStyle(
                    fontSize: 18.0,
                    fontWeight: FontWeight.bold,
                  ),
                ),
              ),
              work.productionCompany != null
                  ? Text(
                      work.productionCompany!,
                      maxLines: 1,
                      overflow: TextOverflow.ellipsis,
                    )
                  : Container(),
            ],
          ),
        ),
        const Spacer(),
        Column(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          crossAxisAlignment: CrossAxisAlignment.end,
          children: [
            Text('⭐ ${work.averageScore.toStringAsFixed(1)}/5', style: const TextStyle(fontSize: 14)),
            Row(
              children: [
                Padding(
                  padding: const EdgeInsets.only(right: 16.0),
                  child: IconButton(
                    onPressed: () => Navigator.pushNamed(context, workScreenRoute, arguments: work.id),
                    icon: Container(
                      height: 35.0,
                      width: 35.0,
                      decoration: const BoxDecoration(shape: BoxShape.circle, color: Color(0xFF3A96AA)),
                      child: const Icon(Icons.remove_red_eye),
                    ),
                  ),
                ),
                IconButton(
                  onPressed: () => showModalBottomSheet(
                    context: context,
                    builder: (ctx) => PersonalWorkStatusModal(work.id),
                  ),
                  icon: Container(
                    height: 35.0,
                    width: 35.0,
                    decoration: const BoxDecoration(shape: BoxShape.circle, color: Color(0xFF3AAA96)),
                    child: Icon(isInUserList ? Icons.edit : Icons.add),
                  ),
                ),
              ],
            ),
          ],
        ),
      ]),
    );
  }
}
