import 'package:collection/collection.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/data/dtos/read_work_details_dto.dart';
import 'package:tcc_app/data/dtos/work_in_personal_list_dto.dart';
import 'package:tcc_app/services/auth_service.dart';
import 'package:tcc_app/services/work_service.dart';

part 'work_event.dart';
part 'work_state.dart';

class WorkBloc extends Bloc<WorkEvent, WorkState> {
  final WorkService workService;
  final AuthService authService;

  WorkBloc({required this.workService, required this.authService}) : super(const InitialWorkState()) {
    on<LoadWorkEvent>((event, emit) => _loadWorkById(event.workId, emit));
  }

  Future<void> _loadWorkById(String workId, Emitter<WorkState> emit) async {
    emit(const LoadingWorkState());
    try {
      final ReadWorkDetailsDto? work = await workService.findById(workId);
      if (work == null) {
        emit(NotFoundWorkState(workId));
      } else {
        final currentUser = await authService.getCurrentUser();
        final userList = await workService.getUserPersonalList(currentUser!);
        final workUserStatus = userList?.firstWhereOrNull((w) => w.work.id == work.id);
        emit(SuccessWorkState(work, workUserStatus));
      }
    } on Exception catch (e) {
      emit(ErrorWorkState(e.toString()));
    }
  }
}