import 'package:flutter/material.dart';
import 'package:tcc_app/data/dtos/read_work_details_dto.dart';
import 'package:tcc_app/data/dtos/work_in_personal_list_dto.dart';
import 'package:tcc_app/screens/work/widgets/person_list.dart';
import 'package:tcc_app/widgets/fade_image.dart';
import 'package:tcc_app/widgets/padding_column.dart';
import 'package:tcc_app/widgets/padding_row.dart';
import 'package:tcc_app/widgets/star_rating.dart';
import 'package:collection/collection.dart';

class WorkWidget extends StatelessWidget {
  final ReadWorkDetailsDto work;
  final WorkInPersonalListDto? workUserStatus;

  const WorkWidget(this.work, this.workUserStatus, {Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final main = work.person?.firstWhereOrNull((element) => element.isMain);

    return SingleChildScrollView(
      physics: const BouncingScrollPhysics(),
      child: Stack(
        children: [
          FadeImage(image: Image.network(work.cover),),
          PaddingColumn(
            padding: const EdgeInsets.all(16.0),
            children: [
              Padding(
                padding: const EdgeInsets.fromLTRB(12, 100, 12, 40),
                child: SizedBox(
                  height: 240,
                  child: Image.network(work.cover),
                ),
              ),
              PaddingRow(
                padding: const EdgeInsets.symmetric(vertical: 8),
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Flexible(
                    child: Text(
                      work.name,
                      style: const TextStyle(
                        fontSize: 24,
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                  ),
                  Column(
                    children: [
                      Row(
                        children: [
                          const Padding(
                            padding: EdgeInsets.all(4.0),
                            child: Icon(Icons.people_outline, size: 16),
                          ),
                          Padding(
                            padding: const EdgeInsets.all(2.0),
                            child: StarRating(
                              work.averageScore,
                              size: 14,
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.all(2.0),
                            child: Text(
                              work.averageScore.toStringAsFixed(1),
                              style: const TextStyle(fontSize: 14),
                            ),
                          ),
                        ],
                      ),
                      if (workUserStatus != null && workUserStatus!.score > 0)
                        Row(
                          children: [
                            const Padding(
                              padding: EdgeInsets.all(4.0),
                              child: Icon(Icons.person, size: 16, color: Colors.yellowAccent),
                            ),
                            Padding(
                              padding: const EdgeInsets.all(2.0),
                              child: StarRating(workUserStatus!.score.toDouble(), size: 14, color: Colors.yellowAccent),
                            ),
                            Padding(
                              padding: const EdgeInsets.all(2.0),
                              child: Text(
                                workUserStatus!.score.toStringAsFixed(1),
                                style: const TextStyle(fontSize: 14, color: Colors.yellowAccent),
                              ),
                            ),
                          ],
                        )
                    ],
                  ),
                ],
              ),
              PaddingRow(
                padding: const EdgeInsets.symmetric(vertical: 4),
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Row(
                    children: [
                      Text(work.releaseYear.toString()),
                      if (work.minuteDuration != null)
                        Wrap(
                          children: [
                            const Padding(
                              padding: EdgeInsets.symmetric(horizontal: 4.0),
                              child: Text('•'),
                            ),
                            Text('${work.minuteDuration} min')
                          ],
                        ),
                      if (work.episodeNumber != null)
                        Wrap(
                          children: [
                            const Padding(
                              padding: EdgeInsets.symmetric(horizontal: 4.0),
                              child: Text('•'),
                            ),
                            Text('${work.episodeNumber} eps')
                          ],
                        )
                    ],
                  ),
                  Text(work.tags.take(2).join('/'))
                ],
              ),
              if (work.productionCompany != null)
                PaddingRow(
                  padding: const EdgeInsets.symmetric(vertical: 4),
                  children: [
                    Text(work.productionCompany!),
                  ],
                ),
              if (main != null)
                PaddingRow(
                  padding: const EdgeInsets.symmetric(vertical: 4),
                  children: [
                    Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Row(
                          children: [
                            Text(
                              (work.type == 'movie' || work.type == 'series') ? 'Dirigido por' : work.type == 'book' ? 'Escrito por' : '',
                              style: TextStyle(fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                        Row(
                          children: [
                            Text(main.person.name),
                          ],
                        ),
                      ],
                    ),
                  ],
                ),
              if (work.synopsis != null)
                PaddingRow(
                  padding: const EdgeInsets.symmetric(vertical: 6),
                  children: [
                    Flexible(
                      child: Text(work.synopsis!),
                    ),
                  ],
                ),
              if (work.person?.isNotEmpty ?? false)
                Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: const [
                        Padding(
                          padding: EdgeInsets.symmetric(vertical: 12.0),
                          child: Text(
                            'Equipe',
                            style: TextStyle(fontWeight: FontWeight.bold, fontSize: 20),
                          ),
                        ),
                      ],
                    ),
                  ],
                ),
              if (work.person?.isNotEmpty ?? false) PersonList(work.person!)
            ],
          ),
        ],
      ),
    );
  }
}
