import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:tcc_app/i18n_consts.dart';
import 'package:tcc_app/screens/personal_work_status/personal_work_status_modal.dart';
import 'package:tcc_app/screens/work/bloc/work_bloc.dart';
import 'package:tcc_app/screens/work/widgets/work_widget.dart';

class WorkScreen extends StatelessWidget {
  const WorkScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final workId = ModalRoute.of(context)!.settings.arguments as String?;

    return BlocBuilder<WorkBloc, WorkState>(
      builder: (context, state) {
        Widget widget;
        String title = '...';
        bool isInList = false;
        if (state is InitialWorkState && workId != null) {
          context.read<WorkBloc>().add(LoadWorkEvent((workId)));
        }
        if (state is SuccessWorkState) {
          widget = WorkWidget(state.work, state.workUserStatus);
          title = workTypeName[state.work.type] ?? '';
          isInList = state.workUserStatus != null;
        } else if (state is LoadingWorkState || state is InitialWorkState) {
          widget = Container(
              alignment: AlignmentDirectional.center,
              child: const CircularProgressIndicator());
        } else {
          widget = Container();
        }

        return Scaffold(
          extendBodyBehindAppBar: true,
          appBar: AppBar(
            title: Text(title.toUpperCase()),
            leading: IconButton(
              onPressed: () => Navigator.pop(context),
              icon: const Icon(Icons.chevron_left_rounded, size: 45),
            ),
            centerTitle: true,
            backgroundColor: Colors.black26,
            shadowColor: Colors.transparent,
            actions: [
              InkWell(
                onTap: () {
                  if (workId != null) {
                    showModalBottomSheet(
                      context: context,
                      builder: (ctx) => PersonalWorkStatusModal(workId),
                    ).then((_) => context.read<WorkBloc>().add(LoadWorkEvent(workId)));
                  }
                },
                child: Padding(
                  padding: const EdgeInsets.all(12.0),
                  child: Icon(isInList ? Icons.edit : Icons.add, size: 32),
                ),
              )
            ],
          ),
          body: widget,
        );
      },
    );
  }
}
