import 'package:dio/dio.dart';
import 'package:tcc_app/data/dtos/create_session_dto.dart';
import 'package:tcc_app/data/dtos/login_request_dto.dart';
import 'package:tcc_app/data/repositories/auth_repository.dart';
import 'package:tcc_app/data/repositories/local_device_repository.dart';

class AuthService {
  static AuthService? _singleton;

  static get instance => _singleton;

  final AuthRepository authRepository;
  final LocalDeviceRepository localRepository;

  AuthService({required this.authRepository, required this.localRepository}) {
    if (_singleton == null) {
      _singleton = this;
    } else {
      throw Exception(
          'An instance of AuthService is already available. Use AuthService.instance.');
    }
  }

  //function to get access token which will be called within the BloC
  Future<CreateSessionDto> loginWithPassword(
      {required String username, required String password}) async {
    LoginRequestDto params =
        LoginRequestDto(username: username, password: password);

    Response? response = await authRepository.login(params: params);

    CreateSessionDto createSessionModel =
        CreateSessionDto.fromResponseContent(response?.data);

    await localRepository.setBearerToken(createSessionModel.accessToken);
    await localRepository.setRefreshToken(createSessionModel.refreshToken);
    await localRepository.setCurrentUser(username);

    return createSessionModel;
  }

  Future<String?> getCurrentUser() async {
    return await localRepository.getCurrentUser();
  }

  Future<String?> verifyToken() async {
    return await authRepository.verifyToken();
  }

  Future<void> logout() async {
    await localRepository.clear();
  }
}
