import 'package:dio/dio.dart';
import 'package:tcc_app/data/dtos/login_to_session_dto.dart';
import 'package:tcc_app/data/dtos/profile_dto.dart';
import 'package:tcc_app/data/dtos/register_request_dto.dart';
import 'package:tcc_app/data/dtos/statistics_model_dto.dart';
import 'package:tcc_app/data/repositories/user_repository.dart';

class UserService {
  static UserService? _singleton;
  static get instance => _singleton;

  UserRepository userRepository;

  UserService({required this.userRepository}) {
    if (_singleton == null) {
      _singleton = this;
    } else {
      throw Exception(
          'An instance of UserService is already available. Use UserService.instance.');
    }
  }

  Future<LoginToSessionDto> registerUser({
    required String name,
    required String username,
    required String password,
    required String birthDate,
    required String email,
  }) async {
    RegisterRequestDto params = RegisterRequestDto(
      name: name,
      username: username,
      email: email,
      birthDate: birthDate,
      password: password,
    );

    await userRepository.registerUser(params: params);

    return LoginToSessionDto(password: password, username: username);
  }

  Future<ProfileDto?> getUserProfile({required String username}) async {
    final Response? response = await userRepository.getUserProfile(username: username);
    
    final profile = ProfileDto.fromResponseContent(response?.data);

    return profile;
  }

  Future<void> editUserProfile({required ProfileDto profile}) async {
    await userRepository.editUserProfile(profile: profile);
  }
}
