import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class TextFormInput extends StatefulWidget {
  final String? hintText;
  final TextEditingController controller;
  final FocusNode? focusNode;
  final String? Function(String?)? validator;
  final bool? obscureText;
  final bool? enabled;
  final List<TextInputFormatter>? formatters;
  final TextInputAction? textInputAction;
  final TextInputType? keyboardType;
  final void Function(String)? onChanged;

  const TextFormInput({
    Key? key,
    this.hintText,
    this.validator,
    this.obscureText,
    required this.controller,
    this.formatters,
    this.keyboardType,
    this.textInputAction, this.enabled = true,
    this.focusNode,
    this.onChanged,
  }) : super(key: key);

  @override
  State<TextFormInput> createState() => _TextFormInputState();
}

class _TextFormInputState extends State<TextFormInput> {
  String? validationResult;

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      controller: widget.controller,
      focusNode: widget.focusNode,
      cursorColor: Colors.white,
      obscureText: widget.obscureText ?? false,
      cursorWidth: 1.0,
      cursorHeight: 20,
      enabled: widget.enabled,
      style: const TextStyle(color: Colors.white, letterSpacing: 1.25, fontSize: 18.0),
      decoration: InputDecoration(
        isCollapsed: true,
        hintStyle: const TextStyle(color: Colors.white38, letterSpacing: 1.25),
        hintText: widget.hintText,
        contentPadding:
            const EdgeInsets.symmetric(vertical: 5.0, horizontal: 1),
        enabledBorder: const UnderlineInputBorder(
            borderSide: BorderSide(color: Colors.white, width: 0.5)),
        focusedBorder: const UnderlineInputBorder(
            borderSide: BorderSide(color: Colors.white, width: 1)),
        border: const UnderlineInputBorder(
            borderSide: BorderSide(color: Colors.white)),
      ),
      textInputAction: widget.textInputAction,
      keyboardType: widget.keyboardType,
      inputFormatters: widget.formatters,
      validator: (value) {
        setState(() {
          if (widget.validator != null) {
            validationResult = widget.validator!(value);
          }
        });
        return validationResult;
      },
      onChanged: widget.onChanged,
    );
  }
}
