import 'package:flutter/material.dart';
import 'package:optimized_cached_image/optimized_cached_image.dart';

class WorkCard extends StatelessWidget {
  final String coverUrl;
  final String name;
  final double height;
  final double width;
  final EdgeInsets? margin;
  final BoxFit fit;

  late final BoxConstraints constraints;

  WorkCard({
    required this.coverUrl,
    required this.name,
    this.margin,
    this.height = 146,
    this.width = 103,
    this.fit = BoxFit.cover,
    Key? key,
  }) : super(key: key) {
    constraints = BoxConstraints.tightFor(
      height: height,
      width: width,
    );
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      constraints: constraints,
      clipBehavior: Clip.hardEdge,
      margin: margin ?? const EdgeInsets.symmetric(horizontal: 8.0),
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(5.0),
          boxShadow: const [
            BoxShadow(
              color: Color(0x40000000),
              blurRadius: 4.0,
              offset: Offset(4.0, 4.0),
            ),
          ]),
      child: OptimizedCacheImage(
        imageUrl: coverUrl,
        height: (constraints.maxHeight * 2),
        width: (constraints.maxWidth * 2),
        fit: fit,
        progressIndicatorBuilder: (context, url, downloadProgress) => Center(
          child: SizedBox(
            width: 25.0,
            height: 25.0,
            child: CircularProgressIndicator(value: downloadProgress.progress),
          ),
        ),
        errorWidget: (context, url, error) => Container(
          constraints: constraints,
          color: Colors.grey.shade600,
          padding: const EdgeInsets.all(10.0),
          child: Center(
            child: Text(
              name,
              style: const TextStyle(fontSize: 15.0),
            ),
          ),
        ),
      ),
    );
  }
}
