import 'package:flutter_test/flutter_test.dart';
import 'package:mocktail/mocktail.dart';
import 'package:tcc_app/data/dtos/register_request_dto.dart';
import 'package:tcc_app/exceptions/app_exception.dart';
import 'package:tcc_app/data/repositories/user_repository.dart';
import 'package:tcc_app/services/user_service.dart';

class UserRepositoryMock extends Mock implements UserRepository {}

const String validBirthDate = '2000-12-31';
const String invalidBirthDate = '0000-00-00';

void main() {
  late UserService userService;
  late UserRepository userRepository;

  setUpAll(() {
    userRepository = UserRepositoryMock();
    userService = UserService(userRepository: userRepository);
  });

  RegisterRequestDto validRegisterParams = _makeValidRegisterParams();
  RegisterRequestDto invalidRegisterParams = _makeInvalidRegisterParams();

  group('Register |', () {
    test("given valid new user data, when it calls 'registerUser', then it should sign up", () {
      when(() => userRepository.registerUser(params: validRegisterParams))
          .thenAnswer((_) async => null);

      expect(
          () => userService.registerUser(
                name: 'valid_name',
                username: 'valid_username',
                email: 'valid@email.com',
                birthDate: validBirthDate,
                password: 'valid_password',
              ),
          returnsNormally);

      verify(() => userRepository.registerUser(params: validRegisterParams))
          .called(1);
    });

    test("given invalid new user data, when it calls 'registerUser', then it should throws", () {
      when(() => userRepository.registerUser(params: invalidRegisterParams))
          .thenThrow(AppException('XX', 'Login failed'));

      expect(
          () => userService.registerUser(
                name: 'invalid_name',
                username: 'invalid_username',
                email: 'invalid@email',
                birthDate: invalidBirthDate,
                password: 'invalid_password',
              ),
          throwsException);

      verify(() => userRepository.registerUser(params: invalidRegisterParams))
          .called(1);
    });
  });
}

RegisterRequestDto _makeValidRegisterParams() {
  return const RegisterRequestDto(
    name: 'valid_name',
    username: 'valid_username',
    email: 'valid@email.com',
    password: 'valid_password',
    birthDate: validBirthDate,
  );
}

RegisterRequestDto _makeInvalidRegisterParams() {
  return const RegisterRequestDto(
    name: 'invalid_name',
    username: 'invalid_username',
    email: 'invalid@email',
    password: 'invalid_password',
    birthDate: invalidBirthDate,
  );
}